@@ -182,7 +182,7 @@ ResultTableSummary2 <- function(y, X, A, LinearT=FALSE, nchain=3, niter=100, nbu
   colnames(temp4) <- c("a.t",paste("a",colnames(alphamat),sep="."),"b.t",paste("b",colnames(betamat),sep="."))
   temp4[,paste("a",colnames(alphamat),sep=".")] <- alphamat
   temp4[,paste("b",colnames(betamat),sep=".")]  <- betamat
-  DIC4 <- compute_ZINB_DIC(y,stfit4,(niter-nburn)/nthin,nchain)
+  DIC4 <- compute_ZINB_DIC(y,stfit4)
   ind4 <- rep(NA,ncol(temp4)); names(ind4) <-  colnames(temp4)
   ind4[paste("a",colnames(alphamat),sep=".")] <- conv.test(stfit4$Alpha)
   ind4[paste("b",colnames(betamat),sep=".")] <- conv.test(stfit4$Beta)
@@ -193,7 +193,7 @@ ResultTableSummary2 <- function(y, X, A, LinearT=FALSE, nchain=3, niter=100, nbu
   temp3 <- data.frame(matrix(NA,nrow(temp4),ncol(temp4)))
   colnames(temp3) <- colnames(temp4)
   temp3[,paste("b",colnames(betamat),sep=".")] <- betamat
-  DIC3 <- compute_NB_DIC(y,stfit3,(niter-nburn)/nthin,nchain)
+  DIC3 <- compute_NB_DIC(y,stfit3)
   ind3 <- rep(NA,length(ind4)); names(ind3) <- names(ind4)
   ind3[paste("b",colnames(betamat),sep=".")] <- conv.test(stfit3$Beta)
 
@@ -204,7 +204,7 @@ ResultTableSummary2 <- function(y, X, A, LinearT=FALSE, nchain=3, niter=100, nbu
   colnames(temp2) <- colnames(temp4)
   temp2[,paste("a",colnames(alphamat),sep=".")] <- alphamat
   temp2[,paste("b",colnames(betamat),sep=".")]  <- betamat
-  DIC2 <- compute_ZINB_DIC(y,stfit2,(niter-nburn)/nthin,nchain)
+  DIC2 <- compute_ZINB_DIC(y,stfit2)
   ind2 <- rep(NA,length(ind4)); names(ind2) <- names(ind4)
   ind2[paste("a",colnames(alphamat),sep=".")] <- conv.test(stfit2$Alpha)
   ind2[paste("b",colnames(betamat),sep=".")] <- conv.test(stfit2$Beta)
@@ -214,7 +214,7 @@ ResultTableSummary2 <- function(y, X, A, LinearT=FALSE, nchain=3, niter=100, nbu
   temp1 <- data.frame(matrix(NA,nrow(temp4),ncol(temp4)))
   colnames(temp1) <- colnames(temp4)
   temp1[,paste("b",colnames(betamat),sep=".")]  <- betamat
-  DIC1 <- compute_NB_DIC(y,stfit1,(niter-nburn)/nthin,nchain)
+  DIC1 <- compute_NB_DIC(y,stfit1)
   ind1 <- rep(NA,length(ind4)); names(ind1) <- names(ind4)
   ind1[paste("b",colnames(betamat),sep=".")] <- conv.test(stfit1$Beta)
 
@@ -276,12 +276,10 @@ ResultTableSummary2 <- function(y, X, A, LinearT=FALSE, nchain=3, niter=100, nbu
 #' @description
 #' Computes DIC for a BSTZINB fitted object
 #'
-#' @usage compute_ZINB_DIC(y,bstfit,lastit,nchain)
+#' @usage compute_ZINB_DIC(y,bstfit)
 #'
 #' @param y vector of counts, must be non-negative, the response used for fitting a BSTZINB model
 #' @param bstfit BSTZINB fitted object
-#' @param lastit positive integer, size of the chain used to fit BSTZINB
-#' @param nchain positive integer, number of chains used to fit BSTZINB
 #'
 #' @importFrom stats cov
 #' @importFrom stats dnbinom
@@ -307,11 +305,11 @@ ResultTableSummary2 <- function(y, X, A, LinearT=FALSE, nchain=3, niter=100, nbu
 #' A <- get_adj_mat(county.adjacency,countyname,c("IA"))
 #' \donttest{
 #' res3 <- BSTZINB(y, X, A, LinearT=TRUE, nchain=3, niter=100, nburn=20, nthin=1)
-#' compute_ZINB_DIC(y,res3,lastit=(100-20)/1,nchain=3)
+#' compute_ZINB_DIC(y,res3)
 #' }
 #'
 #' @export
-compute_ZINB_DIC <- function(y,bstfit,lastit,nchain){
+compute_ZINB_DIC <- function(y,bstfit){
 
   if(is.null(y)){stop("y must be provided")}
   if(!is.vector(y)){stop("y must be a vector")}
@@ -320,10 +318,16 @@ compute_ZINB_DIC <- function(y,bstfit,lastit,nchain){
   if(is.null(bstfit$Eta1)){stop("fit must have a named component Eta1")}
   if(is.null(bstfit$Eta2)){stop("fit must have a named component Eta2")}
   if(is.null(bstfit$R)){stop("fit must have a named component R")}
-  if(!is.numeric(lastit) | lastit <= 0){stop("lastit must be a positive integer")}
-  if(!is.numeric(nchain) | nchain <= 0){stop("nchain must be a positive integer")}
+  # if(!is.numeric(lastit) | lastit <= 0){stop("lastit must be a positive integer")}
+  # if(!is.numeric(nchain) | nchain <= 0){stop("nchain must be a positive integer")}
 
-  computeD.avg <- function(y,bstfit){
+  lastit <- dim(bstfit$Eta1)[3]
+  nchain <- 1
+  if(length(dim(bstfit$Eta1))>3){
+  nchain <- dim(bstfit$Eta1)[4]
+  }
+
+  computeD.avg <- function(y,bstfit,nchain){
     eta1.mean <- apply(bstfit$Eta1,2,mean)
     eta2.mean <- apply(bstfit$Eta2,2,mean)
     r.mean    <- mean(bstfit$R)
@@ -354,7 +358,7 @@ compute_ZINB_DIC <- function(y,bstfit,lastit,nchain){
     }
   }
 
-  comp1 <- computeD.avg(y,bstfit)
+  comp1 <- computeD.avg(y,bstfit,nchain)
   comp2 <- mean(Dmat)
   DIC <- comp1 + 2*( comp2 - comp1)
   return(DIC)
@@ -365,12 +369,10 @@ compute_ZINB_DIC <- function(y,bstfit,lastit,nchain){
 #' @description
 #' Computes DIC for a BSTNB or BNB fitted object
 #'
-#' @usage compute_NB_DIC(y,bstfit,lastit,nchain)
+#' @usage compute_NB_DIC(y,bstfit)
 #'
 #' @param y vector of counts, must be non-negative, the response used for fitting a BSTNB or BSTP model
 #' @param bstfit BSTNB or BNB fitted object
-#' @param lastit positive integer, size of the chain used to fit BSTZINB
-#' @param nchain positive integer, number of chains used to fit BSTZINB
 #'
 #' @importFrom stats cov
 #' @importFrom stats dnbinom
@@ -395,11 +397,11 @@ compute_ZINB_DIC <- function(y,bstfit,lastit,nchain){
 #' A <- get_adj_mat(county.adjacency,countyname,c("IA"))
 #' \donttest{
 #' res2 <- BSTNB(y, X, A, nchain=3, niter=100, nburn=20, nthin=1)
-#' compute_NB_DIC(y,res2,lastit=(100-20)/1,nchain=3)
+#' compute_NB_DIC(y,res2)
 #' }
 #'
 #' @export
-compute_NB_DIC <- function(y,bstfit,lastit,nchain){
+compute_NB_DIC <- function(y,bstfit){
 
   if(is.null(y)){stop("y must be provided")}
   if(!is.vector(y)){stop("y must be a vector")}
@@ -407,8 +409,14 @@ compute_NB_DIC <- function(y,bstfit,lastit,nchain){
   if(min(y,na.rm=T)<0){stop("y must be non-negative")}
   if(is.null(bstfit$Eta1)){stop("fit must have a named component Eta1")}
   if(is.null(bstfit$R)){stop("fit must have a named component R")}
-  if(!is.numeric(lastit) | lastit <= 0){stop("lastit must be a positive integer")}
-  if(!is.numeric(nchain) | nchain <= 0){stop("nchain must be a positive integer")}
+  # if(!is.numeric(lastit) | lastit <= 0){stop("lastit must be a positive integer")}
+  # if(!is.numeric(nchain) | nchain <= 0){stop("nchain must be a positive integer")}
+
+  lastit <- dim(bstfit$Eta1)[3]
+  nchain <- 1
+  if(length(dim(bstfit$Eta1))>3){
+    nchain <- dim(bstfit$Eta1)[4]
+  }
 
   computeD.avg <- function(y,bstfit){
     eta.mean <- apply(bstfit$Eta1,2,mean)
